==> nessai_models-0.2.0.tar.gz: nessai_models-0.2.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.2.0] - 2022-12-16

### Added

- Add models for linear and sinusoidal signals in Gaussian noise.

## [0.1.0] - 2022-09-22

### Added

- Add basic n-dimensional Gaussian
- Add n-dimensional Rosenbrock ([#1](https://github.com/mj-will/nessai-models/pull/1))
- Add n-dimensional Gaussian Mixture Model ([#5](https://github.com/mj-will/nessai-models/pull/5))
- Add n-dimensional HalfGaussian ([#8](https://github.com/mj-will/nessai-models/pull/8))
- Add Gaussian Mixture Model based on a [`cpnest` example](https://github.com/johnveitch/cpnest/blob/master/examples/gaussianmixture.py) ([#5](https://github.com/mj-will/nessai-models/pull/5))
- Add n-dimensional Egg Box based on the version from [Feroz et al. 2008](https://arxiv.org/abs/0809.3437) ([#11](https://github.com/mj-will/nessai-models/pull/11))
- Add n-dimensional Pyramid-like model ([#15](https://github.com/mj-will/nessai-models/pull/15))
- Add basic tests for all models
- Add a basic example ([#21](https://github.com/mj-will/nessai-models/pull/21))

[Unreleased]: https://github.com/mj-will/nessai-models/compare/v0.2.0...HEAD
[0.2.0]: https://github.com/mj-will/nessai-models/compare/v0.1.0...v0.2.0
[0.1.0]: https://github.com/mj-will/nessai-models/releases/tag/v0.1.0

==> nessai_models-0.4.0.tar.gz: nessai_models-0.4.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.4.0] - 2023-06-29

### Added

- Add a Mixture of 1-dimensional distributions likelihood ([#31](https://github.com/mj-will/nessai-models/pull/31))


## [0.3.0] - 2023-02-19

### Added

- Add Brewer likelihood described in [arXiv:0912.2380](https://arxiv.org/abs/0912.2380). ([#28](https://github.com/mj-will/nessai-models/pull/28))

## [0.2.0] - 2022-12-16

### Added

- Add models for linear and sinusoidal signals in Gaussian noise. ([#26](https://github.com/mj-will/nessai-models/pull/26))

## [0.1.0] - 2022-09-22

### Added

- Add basic n-dimensional Gaussian
- Add n-dimensional Rosenbrock ([#1](https://github.com/mj-will/nessai-models/pull/1))
- Add n-dimensional Gaussian Mixture Model ([#5](https://github.com/mj-will/nessai-models/pull/5))
- Add n-dimensional HalfGaussian ([#8](https://github.com/mj-will/nessai-models/pull/8))
- Add Gaussian Mixture Model based on a [`cpnest` example](https://github.com/johnveitch/cpnest/blob/master/examples/gaussianmixture.py) ([#5](https://github.com/mj-will/nessai-models/pull/5))
- Add n-dimensional Egg Box based on the version from [Feroz et al. 2008](https://arxiv.org/abs/0809.3437) ([#11](https://github.com/mj-will/nessai-models/pull/11))
- Add n-dimensional Pyramid-like model ([#15](https://github.com/mj-will/nessai-models/pull/15))
- Add basic tests for all models
- Add a basic example ([#21](https://github.com/mj-will/nessai-models/pull/21))

[Unreleased]: https://github.com/mj-will/nessai-models/compare/v0.4.0...HEAD
[0.4.0]: https://github.com/mj-will/nessai-models/compare/v0.3.0...v0.4.0
[0.3.0]: https://github.com/mj-will/nessai-models/compare/v0.2.0...v0.3.0
[0.2.0]: https://github.com/mj-will/nessai-models/compare/v0.1.0...v0.2.0
[0.1.0]: https://github.com/mj-will/nessai-models/releases/tag/v0.1.0
